@@ -107,6 +107,10 @@ logger.info("Starting WISTX API v%s", settings.api_version)
 @app.on_event("startup")
 async def startup_event() -> None:
     """Initialize services on startup."""
+    from api.auth.oauth import _validate_oauth_config
+    
+    _validate_oauth_config()
+    
     from api.utils.tracing import initialize_tracing
 
     if settings.tracing_enabled:
