@@ -583,9 +583,10 @@ async def logout(
     """
     from api.models.audit_log import AuditEventType, AuditLogSeverity
     from api.services.audit_log_service import audit_log_service
-    from api.utils.cookies import clear_auth_cookie
+    from api.utils.cookies import clear_auth_cookie, REFRESH_COOKIE_NAME
     
     clear_auth_cookie(response)
+    clear_auth_cookie(response, cookie_name=REFRESH_COOKIE_NAME)
     
     ip_address = request.client.host if request.client else None
     user_agent = request.headers.get("user-agent")
