@@ -7,8 +7,9 @@ import logging
 import time
 from typing import Any
 
-from fastapi import APIRouter, Depends, HTTPException, Query, status
+from fastapi import APIRouter, Depends, HTTPException, Query, Request, status
 from fastapi.responses import RedirectResponse
+from starlette.requests import Request
 
 from api.auth.oauth import github_oauth_client, get_oauth_backend_callback_url, get_oauth_frontend_redirect_url
 from api.dependencies import get_current_user
@@ -144,6 +145,7 @@ def get_v1_oauth_callback_url(provider: str) -> str:
 async def github_oauth_callback(
     code: str = Query(...),
     state: str = Query(None),
+    request: Request = None,
 ) -> RedirectResponse:
     """Handle GitHub OAuth callback.
 
@@ -168,7 +170,7 @@ async def github_oauth_callback(
             "SECURITY: GitHub OAuth callback missing state parameter",
             extra={"event": "oauth_state_missing", "provider": "github"},
         )
-        frontend_url = get_oauth_frontend_redirect_url("github")
+        frontend_url = get_oauth_frontend_redirect_url("github", request)
         error_url = f"{frontend_url}?error=invalid_state&message=Missing%20state%20parameter"
         return RedirectResponse(url=error_url)
 
@@ -178,7 +180,7 @@ async def github_oauth_callback(
             "SECURITY: GitHub OAuth callback with invalid/expired state",
             extra={"event": "oauth_state_invalid", "provider": "github", "has_state": bool(state)},
         )
-        frontend_url = get_oauth_frontend_redirect_url("github")
+        frontend_url = get_oauth_frontend_redirect_url("github", request)
         error_url = f"{frontend_url}?error=invalid_state&message=Invalid%20or%20expired%20state%20parameter"
         return RedirectResponse(url=error_url)
     
@@ -239,7 +241,7 @@ async def github_oauth_callback(
             extra={"event": "oauth_token_stored", "provider": "github", "user_id": str(user_id), "is_signup": is_signup},
         )
         
-        frontend_url = get_oauth_frontend_redirect_url("github")
+        frontend_url = get_oauth_frontend_redirect_url("github", request)
         
         if is_signup:
             redirect_url = f"{frontend_url}?onboarding=true"
@@ -256,7 +258,7 @@ async def github_oauth_callback(
             extra={"event": "oauth_callback_error", "provider": "github", "user_id": str(user_id) if user_id else None},
         )
         
-        frontend_url = get_oauth_frontend_redirect_url("github")
+        frontend_url = get_oauth_frontend_redirect_url("github", request)
         if "?" in frontend_url:
             frontend_url += "&github=error"
         else:
@@ -596,6 +598,7 @@ async def list_organization_repositories(
 @router.post("/github/refresh-permissions")
 async def refresh_github_permissions(
     current_user: dict[str, Any] = Depends(get_current_user),
+    request: Request = None,
 ) -> dict[str, Any]:
     """Refresh GitHub OAuth permissions.
 
@@ -624,7 +627,7 @@ async def refresh_github_permissions(
         state=oauth_state,
     )
 
-    frontend_url = get_oauth_frontend_redirect_url("github")
+    frontend_url = get_oauth_frontend_redirect_url("github", request)
     if "?" in frontend_url:
         callback_url = f"{frontend_url}&refresh=organizations"
     else:
