@@ -126,6 +126,8 @@ async def generate_documentation(
                 if auth_ctx.user_info:
                     plan = auth_ctx.user_info.get("plan", "scout")
                 await quota_service.check_query_quota(user_id, plan)
+            except ImportError:
+                logger.debug("API quota service not available, skipping quota check")
             except QuotaExceededError as e:
                 logger.warning("Quota exceeded for user %s: %s", user_id, e)
                 raise RuntimeError(f"Quota exceeded: {e}") from e
