@@ -116,84 +116,162 @@ class MongoDBClient:
             RuntimeError: If connection fails after retries
         """
         if self.client is None:
-            if not settings.mongodb_url:
-                raise ValueError("MongoDB connection string is required. Set MONGODB_URI environment variable.")
-            
-            connection_string = str(settings.mongodb_url).strip().rstrip("/")
-            
-            if not connection_string:
-                raise ValueError("MongoDB connection string is required")
-
             try:
-                from api.config import settings as api_settings
+                if not settings.mongodb_url:
+                    raise ValueError("MongoDB connection string is required. Set MONGODB_URI environment variable.")
+                
+                connection_string = str(settings.mongodb_url).strip().rstrip("/")
+                
+                if not connection_string:
+                    raise ValueError("MongoDB connection string is required")
 
-                motor_options = {
-                    "maxPoolSize": api_settings.mongodb_max_pool_size,
-                    "minPoolSize": api_settings.mongodb_min_pool_size,
-                    "maxIdleTimeMS": api_settings.mongodb_max_idle_time_ms,
-                    "serverSelectionTimeoutMS": api_settings.mongodb_server_selection_timeout_ms,
-                    "connectTimeoutMS": api_settings.mongodb_connect_timeout_ms,
-                    "socketTimeoutMS": api_settings.mongodb_socket_timeout_ms,
-                    "retryWrites": api_settings.mongodb_retry_writes,
-                    "retryReads": True,
-                    "heartbeatFrequencyMS": api_settings.mongodb_heartbeat_frequency_ms,
-                }
-
-                read_pref_map = {
-                    "primary": "primary",
-                    "primarypreferred": "primaryPreferred",
-                    "secondary": "secondary",
-                    "secondarypreferred": "secondaryPreferred",
-                    "nearest": "nearest",
-                }
-                read_pref_str = api_settings.mongodb_read_preference.lower()
-                motor_options["readPreference"] = read_pref_map.get(read_pref_str, "secondaryPreferred")
-
-                self.client = AsyncIOMotorClient(connection_string, **motor_options)
-                self.database = self.client[settings.mongodb_database]
-
-                if not self._registered:
+                api_settings = None
+                try:
+                    import importlib.util
+                    import sys
+                    
+                    spec = importlib.util.find_spec("api.config")
+                    if spec is None:
+                        raise ImportError("api.config module not found")
+                    
+                    module = importlib.util.module_from_spec(spec)
+                    
                     try:
-                        from wistx_mcp.tools.lib.resource_manager import get_resource_manager
-                        resource_manager = await get_resource_manager()
-                        resource_manager.register_mongodb_client(self)
-                        self._registered = True
-                        logger.debug("MongoDB client registered with resource manager")
-                    except (ImportError, AttributeError, RuntimeError) as e:
-                        logger.warning("Could not register MongoDB client with resource manager: %s", e)
+                        spec.loader.exec_module(module)
+                        if hasattr(module, "settings"):
+                            api_settings = module.settings
+                    except SystemExit:
+                        logger.debug("API config failed to initialize (missing required env vars), skipping")
+                        api_settings = None
                     except Exception as e:
-                        logger.warning("Unexpected error registering MongoDB client: %s", e, exc_info=True)
+                        logger.debug("Error loading API config: %s", e)
+                        api_settings = None
+                except ImportError:
+                    logger.debug("API config module not available, using default MongoDB connection options")
+                    api_settings = None
 
-                for attempt in range(self._max_retries):
+                if api_settings:
                     try:
-                        await asyncio.wait_for(
-                            self.client.admin.command("ping"),
-                            timeout=MONGODB_PING_TIMEOUT_SECONDS,
-                        )
-                        logger.info("Connected to MongoDB: %s", settings.mongodb_database)
-                        return
-                    except asyncio.TimeoutError:
-                        if attempt < self._max_retries - 1:
-                            logger.warning(
-                                "MongoDB ping timeout (attempt %d/%d), retrying...",
-                                attempt + 1,
-                                self._max_retries,
-                            )
-                            await asyncio.sleep(self._retry_delay * (attempt + 1))
-                        else:
-                            raise RuntimeError("MongoDB connection timeout after retries")
-                    except (asyncio.TimeoutError, ConnectionError, RuntimeError) as e:
-                        if attempt < self._max_retries - 1:
-                            logger.warning(
-                                "MongoDB connection error (attempt %d/%d): %s, retrying...",
-                                attempt + 1,
-                                self._max_retries,
-                                e,
-                            )
-                            await asyncio.sleep(self._retry_delay * (attempt + 1))
-                        else:
-                            raise RuntimeError(f"Failed to connect to MongoDB after retries: {e}") from e
+                        motor_options = {
+                            "maxPoolSize": api_settings.mongodb_max_pool_size,
+                            "minPoolSize": api_settings.mongodb_min_pool_size,
+                            "maxIdleTimeMS": api_settings.mongodb_max_idle_time_ms,
+                            "serverSelectionTimeoutMS": api_settings.mongodb_server_selection_timeout_ms,
+                            "connectTimeoutMS": api_settings.mongodb_connect_timeout_ms,
+                            "socketTimeoutMS": api_settings.mongodb_socket_timeout_ms,
+                            "retryWrites": api_settings.mongodb_retry_writes,
+                            "retryReads": True,
+                            "heartbeatFrequencyMS": api_settings.mongodb_heartbeat_frequency_ms,
+                        }
 
+                        read_pref_map = {
+                            "primary": "primary",
+                            "primarypreferred": "primaryPreferred",
+                            "secondary": "secondary",
+                            "secondarypreferred": "secondaryPreferred",
+                            "nearest": "nearest",
+                        }
+                        read_pref_str = api_settings.mongodb_read_preference.lower()
+                        motor_options["readPreference"] = read_pref_map.get(read_pref_str, "secondaryPreferred")
+
+                        self.client = AsyncIOMotorClient(connection_string, **motor_options)
+                        self.database = self.client[settings.mongodb_database]
+
+                        if not self._registered:
+                            try:
+                                from wistx_mcp.tools.lib.resource_manager import get_resource_manager
+                                resource_manager = await get_resource_manager()
+                                resource_manager.register_mongodb_client(self)
+                                self._registered = True
+                                logger.debug("MongoDB client registered with resource manager")
+                            except (ImportError, AttributeError, RuntimeError) as e:
+                                logger.warning("Could not register MongoDB client with resource manager: %s", e)
+                            except Exception as e:
+                                logger.warning("Unexpected error registering MongoDB client: %s", e, exc_info=True)
+
+                        for attempt in range(self._max_retries):
+                            try:
+                                await asyncio.wait_for(
+                                    self.client.admin.command("ping"),
+                                    timeout=MONGODB_PING_TIMEOUT_SECONDS,
+                                )
+                                logger.info("Connected to MongoDB: %s", settings.mongodb_database)
+                                return
+                            except asyncio.TimeoutError:
+                                if attempt < self._max_retries - 1:
+                                    logger.warning(
+                                        "MongoDB ping timeout (attempt %d/%d), retrying...",
+                                        attempt + 1,
+                                        self._max_retries,
+                                    )
+                                    await asyncio.sleep(self._retry_delay * (attempt + 1))
+                                else:
+                                    raise RuntimeError("MongoDB connection timeout after retries")
+                            except (asyncio.TimeoutError, ConnectionError, RuntimeError) as e:
+                                if attempt < self._max_retries - 1:
+                                    logger.warning(
+                                        "MongoDB connection error (attempt %d/%d): %s, retrying...",
+                                        attempt + 1,
+                                        self._max_retries,
+                                        e,
+                                    )
+                                    await asyncio.sleep(self._retry_delay * (attempt + 1))
+                                else:
+                                    raise RuntimeError(f"Failed to connect to MongoDB after retries: {e}") from e
+                    except Exception as e:
+                        logger.debug("Error using API config settings, falling back to defaults: %s", e)
+                        api_settings = None
+
+                if not api_settings:
+                    logger.debug("Using default MongoDB connection options")
+                    motor_options = {
+                        "retryWrites": True,
+                        "retryReads": True,
+                    }
+                    self.client = AsyncIOMotorClient(connection_string, **motor_options)
+                    self.database = self.client[settings.mongodb_database]
+
+                    if not self._registered:
+                        try:
+                            from wistx_mcp.tools.lib.resource_manager import get_resource_manager
+                            resource_manager = await get_resource_manager()
+                            resource_manager.register_mongodb_client(self)
+                            self._registered = True
+                            logger.debug("MongoDB client registered with resource manager")
+                        except (ImportError, AttributeError, RuntimeError) as e:
+                            logger.warning("Could not register MongoDB client with resource manager: %s", e)
+                        except Exception as e:
+                            logger.warning("Unexpected error registering MongoDB client: %s", e, exc_info=True)
+
+                    for attempt in range(self._max_retries):
+                        try:
+                            await asyncio.wait_for(
+                                self.client.admin.command("ping"),
+                                timeout=MONGODB_PING_TIMEOUT_SECONDS,
+                            )
+                            logger.info("Connected to MongoDB: %s", settings.mongodb_database)
+                            return
+                        except asyncio.TimeoutError:
+                            if attempt < self._max_retries - 1:
+                                logger.warning(
+                                    "MongoDB ping timeout (attempt %d/%d), retrying...",
+                                    attempt + 1,
+                                    self._max_retries,
+                                )
+                                await asyncio.sleep(self._retry_delay * (attempt + 1))
+                            else:
+                                raise RuntimeError("MongoDB connection timeout after retries")
+                        except (asyncio.TimeoutError, ConnectionError, RuntimeError) as e:
+                            if attempt < self._max_retries - 1:
+                                logger.warning(
+                                    "MongoDB connection error (attempt %d/%d): %s, retrying...",
+                                    attempt + 1,
+                                    self._max_retries,
+                                    e,
+                                )
+                                await asyncio.sleep(self._retry_delay * (attempt + 1))
+                            else:
+                                raise RuntimeError(f"Failed to connect to MongoDB after retries: {e}") from e
             except (ValueError, RuntimeError, ConnectionError) as e:
                 logger.error("Failed to initialize MongoDB client: %s", e, exc_info=True)
                 if self.client is not None:
